@@ -1,13 +1,8 @@
 """Run with multiple processes - sort of emulates AWS Lambda"""
 import multiprocessing
-import time
-import traceback
-import warnings
 
 from ..controllers import ddb as ddb_controller
-from ..controllers import ddb_model as db
-from ..machine import TlMachine
-from ..machine.probe import Probe
+from ..machine.machine import TlMachine
 
 
 class Invoker:
@@ -18,7 +13,7 @@ class Invoker:
     def invoke(self, vmid, run_async=True):
         event = dict(
             # --
-            session_id=self.data_controller.session.session_id,
+            session_id=self.data_controller.session_id,
             vmid=vmid,
         )
         p = multiprocessing.Process(target=resume_handler, args=(event,))
@@ -26,13 +21,10 @@ class Invoker:
 
 
 def resume_handler(event):
+    # TODO catch exceptions and send them back!
     session_id = event["session_id"]
     vmid = event["vmid"]
-    session = db.Session.get(session_id)
-    lock = db.SessionLocker(session)
-    controller = ddb_controller.DataController(session, lock)
+    controller = ddb_controller.DataController.with_session_id(session_id)
     invoker = Invoker(controller)
-
     machine = TlMachine(vmid, invoker)
     machine.run()
-    # TODO return something
